@@ -118,6 +118,7 @@ describe 'designate' do
         :heartbeat_in_pthread               => '<SERVICE DEFAULT>',
         :amqp_durable_queues                => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue                => '<SERVICE DEFAULT>',
+        :rabbit_transient_quorum_queue      => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit       => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes     => '<SERVICE DEFAULT>',
@@ -133,6 +134,7 @@ describe 'designate' do
         :rabbit_ha_queues                => true,
         :rabbit_heartbeat_in_pthread     => true,
         :rabbit_quorum_queue             => true,
+        :rabbit_transient_quorum_queue   => true,
         :rabbit_quorum_delivery_limit    => 3,
         :rabbit_quorum_max_memory_length => 5,
         :rabbit_quorum_max_memory_bytes  => 1073741824,
@@ -148,6 +150,7 @@ describe 'designate' do
       :rabbit_ha_queues                => true,
       :heartbeat_in_pthread            => true,
       :rabbit_quorum_queue             => true,
+      :rabbit_transient_quorum_queue   => true,
       :rabbit_quorum_delivery_limit    => 3,
       :rabbit_quorum_max_memory_length => 5,
       :rabbit_quorum_max_memory_bytes  => 1073741824,
